GSList<T> class

Inheritance

Constructors

GSList({Key? key, required GSListController controller, required OnItemBuilder onItemBuilder, required OnLoadData onLoadData, required int itemCount, bool? paginationEnable, double? height, Widget? emptyWidget, Widget? loadingWidget, Axis? scrollDirection, bool? shrinkWrap, ShimmerProperties? shimmerProperties, bool? enableShimmerLoading, bool? enablePullDownRefresh, ScrollPhysics? physics})

Properties

controller GSListController
final
emptyWidget Widget?
final
enablePullDownRefresh bool?
final
enableShimmerLoading bool?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
itemCount int
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget?
final
onItemBuilder OnItemBuilder
final
onLoadData OnLoadData
final
paginationEnable bool?
final
physics ScrollPhysics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis?
final
shimmerProperties ShimmerProperties?
final
shrinkWrap bool?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GSList<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited